<?php

/*
 * LMS version 1.4.5 Persus
 *
 *  (C) Copyright 2001-2005 LMS Developers
 *
 *  Please, see the doc/AUTHORS for more information about authors!
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License Version 2 as
 *  published by the Free Software Foundation.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307,
 *  USA.
 *
 *  $Id: genfake.php,v 1.22.2.3 2005/01/13 08:46:16 alec Exp $
 */

// Nazwiska

$lastnames[] = "Roszkowski";
$lastnames[] = "Koroza";
$lastnames[] = "Tarkowski";
$lastnames[] = "Jaroszewski";
$lastnames[] = "Matuszak";
$lastnames[] = "Kajszczak";
$lastnames[] = "Charka";
$lastnames[] = "Kaczkowski";
$lastnames[] = "Kebke";
$lastnames[] = "Kaczuba";
$lastnames[] = "Augustyniak";
$lastnames[] = "Lis";
$lastnames[] = "Stachurski";
$lastnames[] = "Kozielski";
$lastnames[] = "ytow";
$lastnames[] = "Kus";
$lastnames[] = "Pajewski";
$lastnames[] = "Jarlaczyski";
$lastnames[] = "Rusek";
$lastnames[] = "Drogowski";
$lastnames[] = "Turowicz";
$lastnames[] = "Szpytma";
$lastnames[] = "Orowski";
$lastnames[] = "Widuliski";
$lastnames[] = "Wierzbiski";
$lastnames[] = "Leniowski";
$lastnames[] = "Kozielski";
$lastnames[] = "Duyski";
$lastnames[] = "Ocha";
$lastnames[] = "Kucybaa";
$lastnames[] = "Bartkowiak";
$lastnames[] = "Lemaski";
$lastnames[] = "Berezowski";
$lastnames[] = "Wjcik";
$lastnames[] = "Ciasto";
$lastnames[] = "Wierzbinski";
$lastnames[] = "Spiradek";
$lastnames[] = "Serocki";
$lastnames[] = "Majek";
$lastnames[] = "Woosz";
$lastnames[] = "Grzybowski";
$lastnames[] = "Siekaski";
$lastnames[] = "Broa";
$lastnames[] = "Radzki";
$lastnames[] = "Czarnecki";
$lastnames[] = "Majza";
$lastnames[] = "Zaczny";
$lastnames[] = "Mnamec";
$lastnames[] = "Krause";
$lastnames[] = "Misiak";
$lastnames[] = "Pdzich";
$lastnames[] = "Marcinkowski";
$lastnames[] = "Luks";
$lastnames[] = "Krzempek";
$lastnames[] = "Tomczyk";
$lastnames[] = "Cebrowski";
$lastnames[] = "Szmidt";
$lastnames[] = "Nalewajk";
$lastnames[] = "Krger";
$lastnames[] = "Kozak";
$lastnames[] = "Bol";
$lastnames[] = "Gajewski";
$lastnames[] = "Kulesza";
$lastnames[] = "Szaniawski";
$lastnames[] = "Kaszuba";
$lastnames[] = "Tkaczyk";
$lastnames[] = "Bonda";
$lastnames[] = "Jarzewski";
$lastnames[] = "Plewka";
$lastnames[] = "Tyrka";
$lastnames[] = "Mucha";
$lastnames[] = "Morlak";
$lastnames[] = "Marciniak";
$lastnames[] = "Rokita";
$lastnames[] = "Okoski";
$lastnames[] = "Szabowski";
$lastnames[] = "Kluska";
$lastnames[] = "Grski";
$lastnames[] = "Gworek";
$lastnames[] = "uszczewski";
$lastnames[] = "Matusiak";
$lastnames[] = "Lobodzinski";
$lastnames[] = "Kapuniak";
$lastnames[] = "Franashtschuk";
$lastnames[] = "Michalik";
$lastnames[] = "Smektaa";
$lastnames[] = "uchniak";
$lastnames[] = "Zontek";
$lastnames[] = "Lesiski";
$lastnames[] = "Hrycyk";
$lastnames[] = "Siemaszko";
$lastnames[] = "Idczak";
$lastnames[] = "Gowacz";
$lastnames[] = "Czeczotko";
$lastnames[] = "Przybylski";
$lastnames[] = "ywczak";
$lastnames[] = "Krakowski";
$lastnames[] = "Zatorski";
$lastnames[] = "Pitkowski";
$lastnames[] = "Kiliaski";
$lastnames[] = "Rycki";
$lastnames[] = "Wawrzonkowski";
$lastnames[] = "Janeczko";
$lastnames[] = "Rozwandowicz";
$lastnames[] = "Guzikowski";
$lastnames[] = "Frontek";
$lastnames[] = "osicki";
$lastnames[] = "Kupidura";
$lastnames[] = "Bocheski";
$lastnames[] = "Maecki";
$lastnames[] = "Mrz";
$lastnames[] = "Jaro";
$lastnames[] = "Potocki";
$lastnames[] = "Gaik";
$lastnames[] = "Nowak";
$lastnames[] = "Onyszkiewicz";
$lastnames[] = "Kowalski";
$lastnames[] = "Flis";
$lastnames[] = "akomy";
$lastnames[] = "Brodowski";
$lastnames[] = "Bieliski";
$lastnames[] = "Zych";
$lastnames[] = "Kuchar";
$lastnames[] = "Dawidowski";
$lastnames[] = "Rostalski";
$lastnames[] = "Purzyski";
$lastnames[] = "Niemczyk";
$lastnames[] = "Krawczyk";
$lastnames[] = "Stybel";
$lastnames[] = "Osikowski";
$lastnames[] = "Starzyski";
$lastnames[] = "Wenda";
$lastnames[] = "Kowalski";
$lastnames[] = "Kolendo";
$lastnames[] = "Matusik";
$lastnames[] = "Tutka";
$lastnames[] = "apin";
$lastnames[] = "Przybylski";
$lastnames[] = "Kowalewski";
$lastnames[] = "Wantua";
$lastnames[] = "Pielat";
$lastnames[] = "Kasper";
$lastnames[] = "uksik";
$lastnames[] = "Bratek";
$lastnames[] = "Wgrzyn";
$lastnames[] = "Rzepa";
$lastnames[] = "ukasz";
$lastnames[] = "Michalczyk";
$lastnames[] = "Wilusz";
$lastnames[] = "Zakrzewski";
$lastnames[] = "Pliszko";
$lastnames[] = "Piechoczek";
$lastnames[] = "Spica";
$lastnames[] = "Szczepaski";
$lastnames[] = "Szunejko";
$lastnames[] = "Grzelczak";
$lastnames[] = "Dominiak";
$lastnames[] = "Woelke";
$lastnames[] = "Granat";
$lastnames[] = "Grzegorz";
$lastnames[] = "Lis";
$lastnames[] = "Wernberger";
$lastnames[] = "Kowalski";
$lastnames[] = "Hajdys";
$lastnames[] = "Pollum";
$lastnames[] = "Winiewski";
$lastnames[] = "Gowacki";
$lastnames[] = "Grams";
$lastnames[] = "Kulpiski";
$lastnames[] = "Cielak";
$lastnames[] = "Malich";
$lastnames[] = "Wrzesiski";
$lastnames[] = "Debiec";
$lastnames[] = "Paszkowski";
$lastnames[] = "Polak";
$lastnames[] = "Rycki";
$lastnames[] = "Spoczyski";
$lastnames[] = "Adamski";
$lastnames[] = "Biel";
$lastnames[] = "Kaczmarek";
$lastnames[] = "Woniak";
$lastnames[] = "Pays";
$lastnames[] = "Traczyski";
$lastnames[] = "Krajewski";
$lastnames[] = "Kowalski";
$lastnames[] = "Fim";
$lastnames[] = "Biaows";
$lastnames[] = "Stoowski";
$lastnames[] = "Ostrowski";
$lastnames[] = "Szopa";
$lastnames[] = "Krawiecki";
$lastnames[] = "Urbaski";
$lastnames[] = "Winkler";
$lastnames[] = "Kaliszka";
$lastnames[] = "aboklicki";
$lastnames[] = "Izydorczyk";
$lastnames[] = "Gwiazda";
$lastnames[] = "Grochowska";
$lastnames[] = "Paasz";
$lastnames[] = "Falana";
$lastnames[] = "Nieborek";
$lastnames[] = "Pluto";
$lastnames[] = "Wesoowski";
$lastnames[] = "Ciuk";
$lastnames[] = "Gowacki";
$lastnames[] = "Paszczyski";
$lastnames[] = "Baowski";
$lastnames[] = "Opaa";
$lastnames[] = "Kaluzny";
$lastnames[] = "Frtczak";
$lastnames[] = "Salwach";
$lastnames[] = "Budzyk";
$lastnames[] = "Nowak";
$lastnames[] = "Kymiski";
$lastnames[] = "Krzaczkowski";
$lastnames[] = "Franecki";
$lastnames[] = "Hrybacz";
$lastnames[] = "Czupryna";
$lastnames[] = "Adamczyk";
$lastnames[] = "Szpakowski";
$lastnames[] = "Piekarek";
$lastnames[] = "Pliszka";
$lastnames[] = "Serwach";
$lastnames[] = "Franczyk";
$lastnames[] = "WME";
$lastnames[] = "Zawakiewicz";
$lastnames[] = "Baa";
$lastnames[] = "Waszek";
$lastnames[] = "Mac";
$lastnames[] = "Olencki";
$lastnames[] = "Raczkowski";
$lastnames[] = "Wojsa";
$lastnames[] = "Czajka";
$lastnames[] = "ukasz";
$lastnames[] = "Paszta";
$lastnames[] = "M.";
$lastnames[] = "Pogoreo";
$lastnames[] = "Mataj";
$lastnames[] = "Izydorczyk";
$lastnames[] = "Jarczak";
$lastnames[] = "Zawadzki";
$lastnames[] = "Zajczkowski";
$lastnames[] = "Kulesza";
$lastnames[] = "Stypua";
$lastnames[] = "Florianini";
$lastnames[] = "Fronczek";
$lastnames[] = "Szczur";
$lastnames[] = "Dziadkiewicz";
$lastnames[] = "Stamblewski";
$lastnames[] = "Zawadzki";
$lastnames[] = "Miklaszewski";
$lastnames[] = "Klemens";
$lastnames[] = "Zasuwik";
$lastnames[] = "Kulczycki";
$lastnames[] = "Krymowski";
$lastnames[] = "Grski";
$lastnames[] = "Migas";
$lastnames[] = "Duda";
$lastnames[] = "Gugaa";
$lastnames[] = "Rafiski";
$lastnames[] = "Baran";
$lastnames[] = "Godzina";
$lastnames[] = "Junak";
$lastnames[] = "Krupnik";
$lastnames[] = "Baraski";
$lastnames[] = "Kujszczyk";
$lastnames[] = "Jaro";
$lastnames[] = "Kdzior";
$lastnames[] = "Baron";
$lastnames[] = "ubiski";
$lastnames[] = "ukasz";
$lastnames[] = "Suszko";
$lastnames[] = "Kajfasz";
$lastnames[] = "Chaubiski";
$lastnames[] = "Kozica";
$lastnames[] = "Puszkarewicz";
$lastnames[] = "Santorski";
$lastnames[] = "Walkiewicz";
$lastnames[] = "Kumierz";
$lastnames[] = "Rudnicki";
$lastnames[] = "Jaworski";
$lastnames[] = "Przybysz";
$lastnames[] = "okaj";
$lastnames[] = "Kozak";
$lastnames[] = "Ulanska";
$lastnames[] = "Jaroszyski";
$lastnames[] = "Ceglarz";
$lastnames[] = "Chaat";
$lastnames[] = "Boym";
$lastnames[] = "Leszczyski";
$lastnames[] = "Bartosiski";
$lastnames[] = "Olejniczak";
$lastnames[] = "Szczygie";
$lastnames[] = "Kajdasz";
$lastnames[] = "Michorowski";
$lastnames[] = "Wysogld";
$lastnames[] = "Warcaba";
$lastnames[] = "Lewandowski";
$lastnames[] = "Zitara";
$lastnames[] = "Has";

// Imiona

$names[] = "Krzysztof";
$names[] = "Adam";
$names[] = "Adrian";
$names[] = "Agata";
$names[] = "Andrzej";
$names[] = "Anna";
$names[] = "Artur";
$names[] = "Barnaba";
$names[] = "Bartek";
$names[] = "Bartomiej";
$names[] = "Bartosz";
$names[] = "Benedykt";
$names[] = "Bogusaw";
$names[] = "Borys";
$names[] = "Boryslaw";
$names[] = "Cezary";
$names[] = "CAW";
$names[] = "Daniel";
$names[] = "Darek";
$names[] = "Dariusz";
$names[] = "Dawid";
$names[] = "Dominik";
$names[] = "Ewelina";
$names[] = "Ferdynand";
$names[] = "Grzegorz";
$names[] = "Hubert";
$names[] = "Ireneusz";
$names[] = "Isztwan";
$names[] = "Iwona";
$names[] = "Jacek";
$names[] = "Jakub";
$names[] = "Jan";
$names[] = "Janusz";
$names[] = "Jarek";
$names[] = "Jaroslaw";
$names[] = "Jarosaw";
$names[] = "Jzef";
$names[] = "Kamil";
$names[] = "Krystian";
$names[] = "Krzysiek";
$names[] = "Krzysztof";
$names[] = "Leszek";
$names[] = "Lucek";
$names[] = "ukasz";
$names[] = "Maciej";
$names[] = "Maciek";
$names[] = "Marcin";
$names[] = "Marek";
$names[] = "Marian";
$names[] = "Mariusz";
$names[] = "Mateusz";
$names[] = "Micha";
$names[] = "Mikoaj";
$names[] = "Miosz";
$names[] = "Mirek";
$names[] = "Noel";
$names[] = "Oskar";
$names[] = "OWICE";
$names[] = "Pawel";
$names[] = "Pawe";
$names[] = "Piotr";
$names[] = "Przemek";
$names[] = "Przemyslaw";
$names[] = "Przemysaw";
$names[] = "Radosaw";
$names[] = "Rafa";
$names[] = "Robert";
$names[] = "Roman";
$names[] = "Ryszard";
$names[] = "Sebastian";
$names[] = "Semko";
$names[] = "Siwik";
$names[] = "Slawek";
$names[] = "Sawek";
$names[] = "Sawomir";
$names[] = "Stanisaw";
$names[] = "Staszek";
$names[] = "Stefan";
$names[] = "Szymon";
$names[] = "Tadeusz";
$names[] = "Tomasz";
$names[] = "Tomek";
$names[] = "Waldemar";
$names[] = "Wako";
$names[] = "Wiktor";
$names[] = "Wadysaw";
$names[] = "Wojciech";
$names[] = "Wojtek";
$names[] = "Wykrt";
$names[] = "ZAWA";
$names[] = "Zbigniew";
$names[] = "Zbyszek";
$names[] = "Zenon";

// Nazwy hostw

$nodenames[] = "JOOLS";
$nodenames[] = "JOPS";
$nodenames[] = "STOO";
$nodenames[] = "RJ";
$nodenames[] = "UBIK";
$nodenames[] = "CJ";
$nodenames[] = "CHRIS";
$nodenames[] = "PETE";
$nodenames[] = "TADGER";
$nodenames[] = "HECTOR";
$nodenames[] = "ELROY";
$nodenames[] = "SOFTY";
$nodenames[] = "MAC";
$nodenames[] = "BOMBER";
$nodenames[] = "STAN";
$nodenames[] = "TOSH";
$nodenames[] = "BRAINS";
$nodenames[] = "NORM";
$nodenames[] = "BUSTER";
$nodenames[] = "SPIKE";
$nodenames[] = "BROWNY";
$nodenames[] = "MURPHY";
$nodenames[] = "KILLER";
$nodenames[] = "ABDUL";
$nodenames[] = "SPOTTY";
$nodenames[] = "GOOFY";
$nodenames[] = "DONALD";
$nodenames[] = "WINDY";
$nodenames[] = "NIFTA";
$nodenames[] = "DENZIL";
$nodenames[] = "CEDRIC";
$nodenames[] = "ALF";
$nodenames[] = "MARTY";
$nodenames[] = "CECIL";
$nodenames[] = "WALLY";
$nodenames[] = "PERVY";
$nodenames[] = "JASON";
$nodenames[] = "ROY";
$nodenames[] = "PEEWEE";
$nodenames[] = "ARNIE";
$nodenames[] = "LOFTY";
$nodenames[] = "TUBBY";
$nodenames[] = "PORKY";
$nodenames[] = "NORRIS";
$nodenames[] = "BUGSY";
$nodenames[] = "GREG";
$nodenames[] = "GUS";
$nodenames[] = "GINGER";
$nodenames[] = "EDDY";
$nodenames[] = "STEVE";
$nodenames[] = "HUGO";
$nodenames[] = "ZIPPY";
$nodenames[] = "SONNY";
$nodenames[] = "WILLY";
$nodenames[] = "MARIO";
$nodenames[] = "LUIGI";
$nodenames[] = "BO";
$nodenames[] = "JOHAN";
$nodenames[] = "COLIN";
$nodenames[] = "QUEENY";
$nodenames[] = "MORGAN";
$nodenames[] = "REG";
$nodenames[] = "PETER";
$nodenames[] = "BRETT";
$nodenames[] = "MATT";
$nodenames[] = "VIC";
$nodenames[] = "HUT";
$nodenames[] = "BUD";
$nodenames[] = "BRAD";
$nodenames[] = "ASHLEY";
$nodenames[] = "LES";
$nodenames[] = "REX";
$nodenames[] = "LOUIS";
$nodenames[] = "PEDRO";
$nodenames[] = "MARCO";
$nodenames[] = "LEON";
$nodenames[] = "ALI";
$nodenames[] = "TYSON";
$nodenames[] = "TIGER";
$nodenames[] = "FRANK";
$nodenames[] = "REUBEN";
$nodenames[] = "LEYTON";
$nodenames[] = "JOSH";
$nodenames[] = "JUDAS";
$nodenames[] = "AJ";
$nodenames[] = "LEX";
$nodenames[] = "BUTCH";
$nodenames[] = "BISON";
$nodenames[] = "GARY";
$nodenames[] = "LUTHER";
$nodenames[] = "KERMIT";
$nodenames[] = "BRIAN";
$nodenames[] = "RAY";
$nodenames[] = "FREAK";
$nodenames[] = "LEROY";
$nodenames[] = "LEE";
$nodenames[] = "BANJO";
$nodenames[] = "BEAKER";
$nodenames[] = "BASIL";
$nodenames[] = "BONZO";
$nodenames[] = "KELVIN";
$nodenames[] = "RONNIE";
$nodenames[] = "RUPERT";
$nodenames[] = "ROO";
$nodenames[] = "DAN";
$nodenames[] = "JIMMY";
$nodenames[] = "RONNIE";
$nodenames[] = "BOB";
$nodenames[] = "DON";
$nodenames[] = "TOMMY";
$nodenames[] = "EDDIE";
$nodenames[] = "OZZY";
$nodenames[] = "MARK";
$nodenames[] = "PADDY";
$nodenames[] = "ARNOLD";
$nodenames[] = "TONY";
$nodenames[] = "TEDDY";
$nodenames[] = "DOM";
$nodenames[] = "THEO";
$nodenames[] = "MARTIN";
$nodenames[] = "CHUNKY";
$nodenames[] = "JON";
$nodenames[] = "BEN";
$nodenames[] = "GIRLY";
$nodenames[] = "JULIAN";
$nodenames[] = "GARY";
$nodenames[] = "PIZZA";
$nodenames[] = "MARK";
$nodenames[] = "CIARAN";
$nodenames[] = "JOCK";
$nodenames[] = "GRAVY";
$nodenames[] = "TRENDY";
$nodenames[] = "NEIL";
$nodenames[] = "DEREK";
$nodenames[] = "ED";
$nodenames[] = "STEVE";
$nodenames[] = "BIFF";
$nodenames[] = "STEVE";
$nodenames[] = "PAUL";
$nodenames[] = "STUART";
$nodenames[] = "RANDY";
$nodenames[] = "LORETA";
$nodenames[] = "SUZIE";
$nodenames[] = "PUMPY";
$nodenames[] = "URMER";
$nodenames[] = "ROGER";
$nodenames[] = "PUSSY";
$nodenames[] = "MEAT";
$nodenames[] = "BEEFY";
$nodenames[] = "HARRY";
$nodenames[] = "TINY";
$nodenames[] = "HOWARD";
$nodenames[] = "MORRIS";
$nodenames[] = "THOR";
$nodenames[] = "REV";
$nodenames[] = "DUKE";
$nodenames[] = "WILLY";
$nodenames[] = "MICKY";
$nodenames[] = "CHAS";
$nodenames[] = "MELONY";
$nodenames[] = "CRAIG";
$nodenames[] = "SIDNEY";
$nodenames[] = "PARSON";
$nodenames[] = "ROWAN";
$nodenames[] = "SMELLY";
$nodenames[] = "DOK";
$nodenames[] = "STEW";
$nodenames[] = "DONALD";
$nodenames[] = "ADRIAN";
$nodenames[] = "PAT";
$nodenames[] = "ICEMAN";
$nodenames[] = "GOOSE";
$nodenames[] = "DIPPY";
$nodenames[] = "VIV";
$nodenames[] = "FAGS";
$nodenames[] = "BUNTY";
$nodenames[] = "NOEL";
$nodenames[] = "BONO";
$nodenames[] = "EDGE";
$nodenames[] = "ROBBIE";
$nodenames[] = "SEAN";
$nodenames[] = "MILES";
$nodenames[] = "JIMI";
$nodenames[] = "GORDON";
$nodenames[] = "VAL";
$nodenames[] = "HOBO";
$nodenames[] = "FUNGUS";
$nodenames[] = "TOILET";
$nodenames[] = "LAMPY";
$nodenames[] = "MARCUS";
$nodenames[] = "PELE";
$nodenames[] = "HUBERT";
$nodenames[] = "JAMES";
$nodenames[] = "TIM";
$nodenames[] = "SAUL";
$nodenames[] = "ANDY";
$nodenames[] = "ALF";
$nodenames[] = "SILKY";
$nodenames[] = "SIMON";
$nodenames[] = "HANDY";
$nodenames[] = "SID";
$nodenames[] = "GEORGE";
$nodenames[] = "JOFF";
$nodenames[] = "BARRY";
$nodenames[] = "DICK";
$nodenames[] = "GIL";
$nodenames[] = "NICK";
$nodenames[] = "TED";
$nodenames[] = "PHIL";
$nodenames[] = "WOODY";
$nodenames[] = "WYNN";
$nodenames[] = "ALAN";
$nodenames[] = "PIP";
$nodenames[] = "MICKEY";
$nodenames[] = "JUSTIN";
$nodenames[] = "KARL";
$nodenames[] = "MADDOG";
$nodenames[] = "HORACE";
$nodenames[] = "HAROLD";
$nodenames[] = "GAZZA";
$nodenames[] = "SPIV";
$nodenames[] = "FOXY";
$nodenames[] = "NED";
$nodenames[] = "BAZIL";
$nodenames[] = "OLIVER";
$nodenames[] = "RETT";
$nodenames[] = "SCOT";
$nodenames[] = "DARREN";
$nodenames[] = "EDWIN";
$nodenames[] = "MOSES";
$nodenames[] = "NOAH";
$nodenames[] = "SETH";
$nodenames[] = "BUDDAH";
$nodenames[] = "MARY";
$nodenames[] = "PILOT";
$nodenames[] = "MCBETH";
$nodenames[] = "MCDUFF";
$nodenames[] = "BELLY";
$nodenames[] = "MATHEW";
$nodenames[] = "MARK";
$nodenames[] = "LUKE";
$nodenames[] = "JOHN";
$nodenames[] = "ASLAM";
$nodenames[] = "HAM";
$nodenames[] = "SHEM";
$nodenames[] = "JOSHUA";
$nodenames[] = "JACOB";
$nodenames[] = "ESAW";
$nodenames[] = "OMAR";
$nodenames[] = "SAUL";
$nodenames[] = "ENOCH";
$nodenames[] = "OBADIA";
$nodenames[] = "DANIEL";
$nodenames[] = "SAMUEL";
$nodenames[] = "BEN";
$nodenames[] = "ROBBO";
$nodenames[] = "JOEBED";
$nodenames[] = "ISMAEL";
$nodenames[] = "ISREAL";
$nodenames[] = "ISABEL";
$nodenames[] = "ISARAT";
$nodenames[] = "MONK";
$nodenames[] = "BLIP";
$nodenames[] = "BACON";
$nodenames[] = "DANUBE";
$nodenames[] = "FRIEND";
$nodenames[] = "DARRYL";
$nodenames[] = "IZZY";
$nodenames[] = "CROSBY";
$nodenames[] = "STILLS";
$nodenames[] = "NASH";
$nodenames[] = "YOUNG";
$nodenames[] = "CHEESE";
$nodenames[] = "SALAMI";
$nodenames[] = "PRAWN";
$nodenames[] = "RADISH";
$nodenames[] = "EGBERT";
$nodenames[] = "EDWY";
$nodenames[] = "EDGAR";
$nodenames[] = "EDWIN";
$nodenames[] = "EDRED";
$nodenames[] = "EGGPIE";
$nodenames[] = "BROS";
$nodenames[] = "SONIC";
$nodenames[] = "ZIGGY";
$nodenames[] = "ALFRED";
$nodenames[] = "SIGGY";
$nodenames[] = "HILDA";
$nodenames[] = "SNELL";
$nodenames[] = "SPARKS";
$nodenames[] = "SPOOK";
$nodenames[] = "TOPCAT";
$nodenames[] = "BENNY";
$nodenames[] = "DIBBLE";
$nodenames[] = "BENKER";
$nodenames[] = "DOSEY";
$nodenames[] = "BEAKY";
$nodenames[] = "JOIST";
$nodenames[] = "PIVOT";
$nodenames[] = "TREE";
$nodenames[] = "BUSH";
$nodenames[] = "GRASS";
$nodenames[] = "SEEDY";
$nodenames[] = "TIN";
$nodenames[] = "ROLLO";
$nodenames[] = "ZIPPO";
$nodenames[] = "NANCY";
$nodenames[] = "LARRY";
$nodenames[] = "IGGY";
$nodenames[] = "NIGEL";
$nodenames[] = "JAMIE";
$nodenames[] = "JESSE";
$nodenames[] = "LEO";
$nodenames[] = "VIRGO";
$nodenames[] = "GARTH";
$nodenames[] = "FIDEL";
$nodenames[] = "IDI";
$nodenames[] = "CHE";
$nodenames[] = "KIRK";
$nodenames[] = "SPOCK";
$nodenames[] = "MACCOY";
$nodenames[] = "CHEKOV";
$nodenames[] = "UHURA";
$nodenames[] = "BONES";
$nodenames[] = "VULCAN";
$nodenames[] = "FESTER";
$nodenames[] = "JETHRO";
$nodenames[] = "JIMBOB";
$nodenames[] = "DECLAN";
$nodenames[] = "DALEK";
$nodenames[] = "HICKEY";
$nodenames[] = "CHOCCO";
$nodenames[] = "GOCH";
$nodenames[] = "PABLO";
$nodenames[] = "RENOIR";
$nodenames[] = "ROLF";
$nodenames[] = "DALI";
$nodenames[] = "MONET";
$nodenames[] = "MANET";
$nodenames[] = "GAUGIN";
$nodenames[] = "CHAGAL";
$nodenames[] = "KID";
$nodenames[] = "HULLY";
$nodenames[] = "ROBERT";
$nodenames[] = "PIERS";
$nodenames[] = "RAITH";
$nodenames[] = "JEEVES";
$nodenames[] = "PASTER";
$nodenames[] = "ADOLF";
$nodenames[] = "DEITER";
$nodenames[] = "DENI";
$nodenames[] = "ZARK";
$nodenames[] = "WIZKID";
$nodenames[] = "WIZARD";
$nodenames[] = "IAIN";
$nodenames[] = "KITTEN";
$nodenames[] = "GONNER";
$nodenames[] = "WASTER";
$nodenames[] = "LOSER";
$nodenames[] = "FODDER";
$nodenames[] = "CYCLOP";
$nodenames[] = "STORM";
$nodenames[] = "COLOSSUS";
$nodenames[] = "WOLVERINE";
$nodenames[] = "ROGUE";
$nodenames[] = "BEAST";
$nodenames[] = "PHONIX";
$nodenames[] = "MORPH";
$nodenames[] = "BAMSHE";
$nodenames[] = "ANGEL";
$nodenames[] = "DAZZLER";
$nodenames[] = "JUBILEE";
$nodenames[] = "GAMBIT";
$nodenames[] = "PUNISHER";
$nodenames[] = "IRONMAN";
$nodenames[] = "HULK";
$nodenames[] = "SPIDERMAN";
$nodenames[] = "THOR";
$nodenames[] = "OCTOPUS";
$nodenames[] = "VENOM";
$nodenames[] = "REDSKULL";
$nodenames[] = "SCORPION";
$nodenames[] = "OMEGARED";
$nodenames[] = "RAMBO";
$nodenames[] = "ROCKY";
$nodenames[] = "COMMANDO";
$nodenames[] = "PREDATOR";
$nodenames[] = "BLADE";
$nodenames[] = "CYCL0P";
$nodenames[] = "ST0RM";
$nodenames[] = "C0LOSSUS";
$nodenames[] = "W0LVERINE";
$nodenames[] = "R0GUE";
$nodenames[] = "B3AST";
$nodenames[] = "PH0NIX";
$nodenames[] = "M0RPH";
$nodenames[] = "B4MSHE";
$nodenames[] = "ANG3L";
$nodenames[] = "D4ZZLER";
$nodenames[] = "JUB1LEE";
$nodenames[] = "G4MBIT";
$nodenames[] = "PUN1SHER";
$nodenames[] = "IR0NMAN";
$nodenames[] = "SP1DERMAN";
$nodenames[] = "TH0R";
$nodenames[] = "OC7OPUS";
$nodenames[] = "V3NOM";
$nodenames[] = "R3DSKULL";
$nodenames[] = "SC0RPION";
$nodenames[] = "OM3GARED";
$nodenames[] = "R4MBO";
$nodenames[] = "R0CKY";
$nodenames[] = "C0MMANDO";
$nodenames[] = "PR3DATOR";
$nodenames[] = "BL4DE";
$nodenames[] = "COL0SSUS";
$nodenames[] = "WOLV3RINE";
$nodenames[] = "BE4ST";
$nodenames[] = "PHON1X";
$nodenames[] = "BAM5HE";
$nodenames[] = "DA22LER";
$nodenames[] = "JUBIL3E";
$nodenames[] = "GAMB1T";
$nodenames[] = "PUNI5HER";
$nodenames[] = "IRONM4N";
$nodenames[] = "SPID3RMAN";
$nodenames[] = "OCT0PUS";
$nodenames[] = "VEN0M";
$nodenames[] = "RED5KULL";
$nodenames[] = "SCORP1ON";
$nodenames[] = "OMEG4RED";
$nodenames[] = "COMM4NDO";
$nodenames[] = "PRED4TOR";
$nodenames[] = "COLO55US";
$nodenames[] = "WOLVER1NE";
$nodenames[] = "BEA5T";
$nodenames[] = "PH0N1X";
$nodenames[] = "B4M5HE";
$nodenames[] = "DAZZL3R";
$nodenames[] = "JUB1L3E";
$nodenames[] = "G4MB1T";
$nodenames[] = "PUNISH3R";
$nodenames[] = "IR0NM4N";
$nodenames[] = "SPIDERM4N";
$nodenames[] = "OC70PUS";
$nodenames[] = "V3N0M";
$nodenames[] = "R3D5KULL";
$nodenames[] = "SCORPI0N";
$nodenames[] = "OMEGAR3D";
$nodenames[] = "C0MM4NDO";
$nodenames[] = "PREDA7OR";
$nodenames[] = "C0L0SSUS";
$nodenames[] = "W0LV3RINE";
$nodenames[] = "B34ST";
$nodenames[] = "D422LER";
$nodenames[] = "PUN15HER";
$nodenames[] = "SP1D3RMAN";
$nodenames[] = "SC0RP1ON";
$nodenames[] = "OM3G4RED";
$nodenames[] = "PREDAT0R";
$nodenames[] = "C0LO55US";
$nodenames[] = "W0LVER1NE";
$nodenames[] = "B3A5T";
$nodenames[] = "D4ZZL3R";
$nodenames[] = "PUN1SH3R";
$nodenames[] = "SP1DERM4N";
$nodenames[] = "SC0RPI0N";
$nodenames[] = "OM3GAR3D";
$nodenames[] = "PR3D4TOR";
$nodenames[] = "COL055US";
$nodenames[] = "WOLV3R1NE";
$nodenames[] = "BE45T";
$nodenames[] = "DA22L3R";
$nodenames[] = "PUNI5H3R";
$nodenames[] = "SPID3RM4N";
$nodenames[] = "SCORP10N";
$nodenames[] = "OMEG4R3D";
$nodenames[] = "PR3DA7OR";
$nodenames[] = "COL055US";
$nodenames[] = "W0LV3R1NE";
$nodenames[] = "B345T";
$nodenames[] = "D422L3R";
$nodenames[] = "PUN15H3R";
$nodenames[] = "SP1D3RM4N";
$nodenames[] = "SC0RP10N";
$nodenames[] = "OM3G4R3D";
$nodenames[] = "PR3DAT0R";
$nodenames[] = "PRED47OR";
$nodenames[] = "PRED4T0R";
$nodenames[] = "PRED470R";
$nodenames[] = "PR3D47OR";
$nodenames[] = "PR3DA70R";
$nodenames[] = "PR3D4T0R";
$nodenames[] = "PR3D470R";
$nodenames[] = "ACHILLES";
$nodenames[] = "ACIS";
$nodenames[] = "ADMET";
$nodenames[] = "ADONIS";
$nodenames[] = "AFRODYTA";
$nodenames[] = "AGAMEMNON";
$nodenames[] = "AGAWE";
$nodenames[] = "AJAKOS";
$nodenames[] = "AJAKS";
$nodenames[] = "AKRIZJOS";
$nodenames[] = "ABAS";
$nodenames[] = "AKTEON";
$nodenames[] = "AKWILON";
$nodenames[] = "ALKESTIS";
$nodenames[] = "ALKINOOS";
$nodenames[] = "ALKMENA";
$nodenames[] = "ALKMEON";
$nodenames[] = "ALTEJA";
$nodenames[] = "ALMATEA";
$nodenames[] = "AMFIARAAS";
$nodenames[] = "AMFION";
$nodenames[] = "AMFIRON";
$nodenames[] = "AMFRYTA";
$nodenames[] = "AMOR";
$nodenames[] = "ANCHIZES";
$nodenames[] = "ANDROKLES";
$nodenames[] = "ANDROMEDA";
$nodenames[] = "ANTEUSZ";
$nodenames[] = "ANTINOOS";
$nodenames[] = "ANTIOPA";
$nodenames[] = "ANTYGONA";
$nodenames[] = "ARGOS";
$nodenames[] = "ARGUS";
$nodenames[] = "APOLLO";
$nodenames[] = "ARACHNE";
$nodenames[] = "ARES";
$nodenames[] = "ARIADNA";
$nodenames[] = "ARTEMIDA";
$nodenames[] = "ASKANIUSZ";
$nodenames[] = "ASKLEPIOS";
$nodenames[] = "ASTANAKS";
$nodenames[] = "ATLANTA";
$nodenames[] = "ATAMAS";
$nodenames[] = "ATE";
$nodenames[] = "ATENA";
$nodenames[] = "ATLAS";
$nodenames[] = "ATREUSZ";
$nodenames[] = "ATTIS";
$nodenames[] = "AUGE";
$nodenames[] = "AUGIASZ";
$nodenames[] = "AURORA";
$nodenames[] = "BACHUS";
$nodenames[] = "BAUCIS";
$nodenames[] = "BITON";
$nodenames[] = "BOREASZ";
$nodenames[] = "BRYZEJDA";
$nodenames[] = "BUZYRYS";
$nodenames[] = "CERBER";
$nodenames[] = "CENTAUR";
$nodenames[] = "CERERA";
$nodenames[] = "CHAOS";
$nodenames[] = "CHARON";
$nodenames[] = "CHARYBDA";
$nodenames[] = "CHARYTA";
$nodenames[] = "CHIMERA";
$nodenames[] = "CHIRON";
$nodenames[] = "CHLORIS";
$nodenames[] = "CHRONOS";
$nodenames[] = "CHRYZEIDA";
$nodenames[] = "CYKLOP";
$nodenames[] = "DAFNE";
$nodenames[] = "DAMOSTES";
$nodenames[] = "DANAE";
$nodenames[] = "DEDAL";
$nodenames[] = "DEIFOBOS";
$nodenames[] = "DEJANIRA";
$nodenames[] = "DEMETER";
$nodenames[] = "DEUKALION";
$nodenames[] = "DIOMEDES";
$nodenames[] = "DIONIZOS";
$nodenames[] = "DIRKE";
$nodenames[] = "DIS_PATER";
$nodenames[] = "DYDONA";
$nodenames[] = "EAK";
$nodenames[] = "ECHIDNA";
$nodenames[] = "ECHO";
$nodenames[] = "EDYP";
$nodenames[] = "EFIATLES";
$nodenames[] = "EGERIA";
$nodenames[] = "EGEUSZ";
$nodenames[] = "EGIST";
$nodenames[] = "EIRENE";
$nodenames[] = "ELAIS";
$nodenames[] = "ELEKTRA";
$nodenames[] = "ENDYMION";
$nodenames[] = "ENEASZ";
$nodenames[] = "EOL";
$nodenames[] = "EOS";
$nodenames[] = "ERATO";
$nodenames[] = "EREB";
$nodenames[] = "ERIGONE";
$nodenames[] = "ERIS";
$nodenames[] = "EROS";
$nodenames[] = "ETEOKLES";
$nodenames[] = "EUMAJOS";
$nodenames[] = "EUROPA";
$nodenames[] = "EUROS";
$nodenames[] = "EURYDYKA";
$nodenames[] = "EURKLEJA";
$nodenames[] = "EUTERPE";
$nodenames[] = "FAETON";
$nodenames[] = "FAMA";
$nodenames[] = "FAON";
$nodenames[] = "FATUM";
$nodenames[] = "FAUN";
$nodenames[] = "FAUNA";
$nodenames[] = "FEBE";
$nodenames[] = "FEBUS";
$nodenames[] = "FEDRA";
$nodenames[] = "FENIKS";
$nodenames[] = "FERONIA";
$nodenames[] = "FILEMON";
$nodenames[] = "FILOKTET";
$nodenames[] = "FILOMELA";
$nodenames[] = "FINEUS";
$nodenames[] = "FLORA";
$nodenames[] = "FOKOS";
$nodenames[] = "FORTUNA";
$nodenames[] = "FRYKSOS";
$nodenames[] = "FYLLIS";
$nodenames[] = "GAJA";
$nodenames[] = "GALATEA";
$nodenames[] = "GANIMEDES";
$nodenames[] = "GERYON";
$nodenames[] = "GLAUKOS";
$nodenames[] = "GORDIOS";
$nodenames[] = "HADES";
$nodenames[] = "HARMONIA";
$nodenames[] = "HEBE";
$nodenames[] = "HEFAJSTOS";
$nodenames[] = "HEKABE";
$nodenames[] = "HEKATE";
$nodenames[] = "HEKTOR";
$nodenames[] = "HEKUBA";
$nodenames[] = "HELENOS";
$nodenames[] = "HELIOS";
$nodenames[] = "HELLE";
$nodenames[] = "HELLEN";
$nodenames[] = "HERA";
$nodenames[] = "HERAKLES";
$nodenames[] = "HERMES";
$nodenames[] = "HERMIONA";
$nodenames[] = "HERO";
$nodenames[] = "HERSILIA";
$nodenames[] = "HESTIA";
$nodenames[] = "HEZJONE";
$nodenames[] = "HIACYNT";
$nodenames[] = "HIGIEJA";
$nodenames[] = "HYADA";
$nodenames[] = "HYMEN";
$nodenames[] = "HYPNOS";
$nodenames[] = "HYPSIPYLE";
$nodenames[] = "IDAS";
$nodenames[] = "IFIGENIA";
$nodenames[] = "IKAR";
$nodenames[] = "IKARIOS";
$nodenames[] = "IKSJON";
$nodenames[] = "INO";
$nodenames[] = "IO";
$nodenames[] = "IRIS";
$nodenames[] = "IROS";
$nodenames[] = "ISMENA";
$nodenames[] = "IZYDA";
$nodenames[] = "JANUS";
$nodenames[] = "JAZJON";
$nodenames[] = "JAZON";
$nodenames[] = "JOKASTA";
$nodenames[] = "JOWISZ";
$nodenames[] = "JUNO";
$nodenames[] = "JUNONA";
$nodenames[] = "JUPPITER";
$nodenames[] = "JUTURNA";
$nodenames[] = "KADMOS";
$nodenames[] = "KAKUS";
$nodenames[] = "KALAIS";
$nodenames[] = "KALCHAS";
$nodenames[] = "KALIOPE";
$nodenames[] = "KALIPSO";
$nodenames[] = "KAMILLA";
$nodenames[] = "KASANDRA";
$nodenames[] = "KASJOPEJA";
$nodenames[] = "KASTOR";
$nodenames[] = "KEFALOS";
$nodenames[] = "KEKROPS";
$nodenames[] = "KERKION";
$nodenames[] = "KIKLOP";
$nodenames[] = "KIRKE";
$nodenames[] = "KLEOBIS";
$nodenames[] = "KLIO";
$nodenames[] = "KORA";
$nodenames[] = "KORONIS";
$nodenames[] = "KREON";
$nodenames[] = "KREUZA";
$nodenames[] = "KRONOS";
$nodenames[] = "KUPIDO";
$nodenames[] = "KWIRYNUS";
$nodenames[] = "KYBELE";
$nodenames[] = "LABDAKOS";
$nodenames[] = "LAERTES";
$nodenames[] = "LAJOS";
$nodenames[] = "LAMIA";
$nodenames[] = "LAODAMIA";
$nodenames[] = "LAOKOON";
$nodenames[] = "LAOMEDON";
$nodenames[] = "LATONA";
$nodenames[] = "LATYNUS";
$nodenames[] = "LEANDER";
$nodenames[] = "LEDA";
$nodenames[] = "LETO";
$nodenames[] = "LEUKOTEA";
$nodenames[] = "LIBITINA";
$nodenames[] = "LIKAON";
$nodenames[] = "LIKOMEDES";
$nodenames[] = "LIKOS";
$nodenames[] = "LIKURG";
$nodenames[] = "LINOS";
$nodenames[] = "LUNA";
$nodenames[] = "LYNKEUS";
$nodenames[] = "MAJA";
$nodenames[] = "MAJRA";
$nodenames[] = "MARPESSA";
$nodenames[] = "MARS";
$nodenames[] = "MARSJASZ";
$nodenames[] = "MATER";
$nodenames[] = "MEDEA";
$nodenames[] = "MEDUZA";
$nodenames[] = "MELAMPUS";
$nodenames[] = "MELEAGER";
$nodenames[] = "MELPOMENA";
$nodenames[] = "MEMNON";
$nodenames[] = "MENELAOS";
$nodenames[] = "MENTOR";
$nodenames[] = "MERKURY";
$nodenames[] = "METIS";
$nodenames[] = "MIDAS";
$nodenames[] = "MINERWA";
$nodenames[] = "MINOS";
$nodenames[] = "MINOTAUR";
$nodenames[] = "MINYAS";
$nodenames[] = "MITRA";
$nodenames[] = "MNEMOZYNE";
$nodenames[] = "MOMOS";
$nodenames[] = "NARCYZ";
$nodenames[] = "NAUZYKAA";
$nodenames[] = "NEMEZIS";
$nodenames[] = "NEPTUN";
$nodenames[] = "NEREUS";
$nodenames[] = "NESSOS";
$nodenames[] = "NESTOR";
$nodenames[] = "NIKE";
$nodenames[] = "NIOBE";
$nodenames[] = "NOTOS";
$nodenames[] = "ODYSEUSZ";
$nodenames[] = "OINEUS";
$nodenames[] = "OINMAOS";
$nodenames[] = "OINONE";
$nodenames[] = "OINO";
$nodenames[] = "OKEANOS";
$nodenames[] = "OPS";
$nodenames[] = "OREJTYJA";
$nodenames[] = "ORESTES";
$nodenames[] = "ORFEUSZ";
$nodenames[] = "ORION";
$nodenames[] = "ORKUS";
$nodenames[] = "OTOS";
$nodenames[] = "PALAMEDES";
$nodenames[] = "PALEMON";
$nodenames[] = "PALES";
$nodenames[] = "PALLAS";
$nodenames[] = "PAN";
$nodenames[] = "PANDORA";
$nodenames[] = "PARYS";
$nodenames[] = "PASIFAE";
$nodenames[] = "PATROKLOS";
$nodenames[] = "PEGAZ";
$nodenames[] = "PEJRITOOS";
$nodenames[] = "PELEUS";
$nodenames[] = "PELOPS";
$nodenames[] = "PENELOPA";
$nodenames[] = "PENTEUSZ";
$nodenames[] = "PERSEFONA";
$nodenames[] = "PERSEUSZ";
$nodenames[] = "PIGMALION";
$nodenames[] = "PIKUS";
$nodenames[] = "PITYS";
$nodenames[] = "PLUTON";
$nodenames[] = "PLUTOS";
$nodenames[] = "POLIDOROS";
$nodenames[] = "POLIFEM";
$nodenames[] = "POLIKSENA";
$nodenames[] = "POLINIK";
$nodenames[] = "POLLUKS";
$nodenames[] = "POLYPEMON";
$nodenames[] = "POMONA";
$nodenames[] = "POSEJDON";
$nodenames[] = "PRIAM";
$nodenames[] = "PRIAP";
$nodenames[] = "PROKNE";
$nodenames[] = "PROKRIS";
$nodenames[] = "PROTEUSZ";
$nodenames[] = "PSYCHE";
$nodenames[] = "PYLADES";
$nodenames[] = "PYRAM";
$nodenames[] = "PYRRA";
$nodenames[] = "PYTIA";
$nodenames[] = "PYTON";
$nodenames[] = "REA";
$nodenames[] = "REZOS";
$nodenames[] = "ROMULUS";
$nodenames[] = "REMUS";
$nodenames[] = "SARPEDON";
$nodenames[] = "SATURN";
$nodenames[] = "SATYR";
$nodenames[] = "SCYLLA";
$nodenames[] = "SELENE";
$nodenames[] = "SEMELE";
$nodenames[] = "SFINKS";
$nodenames[] = "SILVANUS";
$nodenames[] = "SKIRON";
$nodenames[] = "SKYLLA";
$nodenames[] = "SOL";
$nodenames[] = "SPERMO";
$nodenames[] = "STENTOR";
$nodenames[] = "SYBILLA";
$nodenames[] = "SYLEN";
$nodenames[] = "SYRINKS";
$nodenames[] = "SYZYF";
$nodenames[] = "TALIA";
$nodenames[] = "TANATOS";
$nodenames[] = "TANTAL";
$nodenames[] = "TELAMON";
$nodenames[] = "TELEFOS";
$nodenames[] = "TELEGONOS";
$nodenames[] = "TELEMACH";
$nodenames[] = "TELLUS";
$nodenames[] = "TEMIDA";
$nodenames[] = "TEREUS";
$nodenames[] = "TERRA";
$nodenames[] = "TERSYTES";
$nodenames[] = "TETYDA";
$nodenames[] = "TEUKROS";
$nodenames[] = "TEZEUSZ";
$nodenames[] = "TITONOS";
$nodenames[] = "TITYOS";
$nodenames[] = "TROILAS";
$nodenames[] = "TURNUS";
$nodenames[] = "TYCHE";
$nodenames[] = "TYESTES";
$nodenames[] = "TYFON";
$nodenames[] = "TYNDAREOS";
$nodenames[] = "TYTIO";
$nodenames[] = "TYSBE";
$nodenames[] = "ULISSES";
$nodenames[] = "URANIA";
$nodenames[] = "URANOS";
$nodenames[] = "VICTORIA";
$nodenames[] = "WENUS";
$nodenames[] = "WESTA";
$nodenames[] = "WULKAN";
$nodenames[] = "ZEFIR";
$nodenames[] = "ZETES";
$nodenames[] = "ZETOS";
$nodenames[] = "ZEUS";
$nodenames[] = "ANDVARI";
$nodenames[] = "ASKR";
$nodenames[] = "AURGELMIR";
$nodenames[] = "BALDUR";
$nodenames[] = "BALDR";
$nodenames[] = "BALDER";
$nodenames[] = "BRAGI";
$nodenames[] = "EMBDA";
$nodenames[] = "FENRIR";
$nodenames[] = "FREYJA";
$nodenames[] = "FREYR";
$nodenames[] = "FRIGGA";
$nodenames[] = "FRIIA";
$nodenames[] = "HEIMDALL";
$nodenames[] = "HEL";
$nodenames[] = "HERMOD";
$nodenames[] = "HODOR";
$nodenames[] = "HEDR";
$nodenames[] = "HODER";
$nodenames[] = "IDUMA";
$nodenames[] = "IGDRASIL";
$nodenames[] = "IMIR";
$nodenames[] = "INGVI";
$nodenames[] = "JORD";
$nodenames[] = "KVASIR";
$nodenames[] = "LIF";
$nodenames[] = "MIMIR";
$nodenames[] = "NANNA";
$nodenames[] = "NIDHOGG";
$nodenames[] = "NJORD";
$nodenames[] = "NJORTH";
$nodenames[] = "ODNIR";
$nodenames[] = "ODR";
$nodenames[] = "OTHR";
$nodenames[] = "ODYN";
$nodenames[] = "SIF";
$nodenames[] = "SIGUNA";
$nodenames[] = "SIGURD";
$nodenames[] = "SKADI";
$nodenames[] = "SLEIPNIR";
$nodenames[] = "THOR";
$nodenames[] = "TYR";
$nodenames[] = "TIU";
$nodenames[] = "VALI";
$nodenames[] = "VIDAR";
$nodenames[] = "AMON";
$nodenames[] = "ANUBIS";
$nodenames[] = "ANPU";
$nodenames[] = "APIS";
$nodenames[] = "HAPE";
$nodenames[] = "HAPI";
$nodenames[] = "ATON";
$nodenames[] = "ATUM";
$nodenames[] = "BASTET";
$nodenames[] = "BAST";
$nodenames[] = "BES";
$nodenames[] = "BISU";
$nodenames[] = "BUTO";
$nodenames[] = "CHONSU";
$nodenames[] = "GEB";
$nodenames[] = "KEB";
$nodenames[] = "SEB";
$nodenames[] = "HATHOR";
$nodenames[] = "HORUS";
$nodenames[] = "HOR";
$nodenames[] = "IZYDA";
$nodenames[] = "ISIS";
$nodenames[] = "MAAT";
$nodenames[] = "MIN";
$nodenames[] = "MUT";
$nodenames[] = "NECHBET";
$nodenames[] = "NEFTYDA";
$nodenames[] = "NEIT";
$nodenames[] = "NUT";
$nodenames[] = "OZYRYS";
$nodenames[] = "PTAH";
$nodenames[] = "RE";
$nodenames[] = "RA";
$nodenames[] = "SECHMET";
$nodenames[] = "SECHTET";
$nodenames[] = "SERAPIS";
$nodenames[] = "SET";
$nodenames[] = "SOBEK";
$nodenames[] = "SZU";
$nodenames[] = "TOTH";
$nodenames[] = "ADAD";
$nodenames[] = "AN";
$nodenames[] = "BAU";
$nodenames[] = "BELIT";
$nodenames[] = "DUMUZI";
$nodenames[] = "EA";
$nodenames[] = "ENKI";
$nodenames[] = "HADAD";
$nodenames[] = "HAD";
$nodenames[] = "HADDA";
$nodenames[] = "INANNA";
$nodenames[] = "ISZKUR";
$nodenames[] = "ISZTAR";
$nodenames[] = "LAMASZTU";
$nodenames[] = "MARDUK";
$nodenames[] = "NABU";
$nodenames[] = "NANNA";
$nodenames[] = "NERGAL";
$nodenames[] = "NINHURSAG";
$nodenames[] = "NINLIL";
$nodenames[] = "NINURTA";
$nodenames[] = "NUSKU";
$nodenames[] = "SIN";
$nodenames[] = "TAMMZU";
$nodenames[] = "UTU";

$streets[] = "Wiosenna";
$streets[] = "Biaostocka";
$streets[] = "Tarchomiska";
$streets[] = "Zbkowska";
$streets[] = "Idzikowskiego";
$streets[] = "Czerniakowska";
$streets[] = "Stalowa";
$streets[] = "Rakowiecka";
$streets[] = "Anieli Krzywo";
$streets[] = "Piotrkowska";
$streets[] = "Kijowska";
$streets[] = "Skierniewicka";
$streets[] = "Roszkowskiego";

$phoneprefix[] = "0501";
$phoneprefix[] = "0502";
$phoneprefix[] = "0503";
$phoneprefix[] = "0504";
$phoneprefix[] = "0505";
$phoneprefix[] = "0506";
$phoneprefix[] = "0601";
$phoneprefix[] = "0602";
$phoneprefix[] = "0603";
$phoneprefix[] = "0604";
$phoneprefix[] = "0605";
$phoneprefix[] = "0606";
$phoneprefix[] = "0607";
$phoneprefix[] = "0608";
$phoneprefix[] = "0609";
$phoneprefix[] = "0691";
$phoneprefix[] = "0692";
$phoneprefix[] = "8";
$phoneprefix[] = "6";
$phoneprefix[] = "5";
$phoneprefix[] = "4";
$phoneprefix[] = "3";

$emaildomains[] = "wiosenna.net";
$emaildomains[] = "wiosenna.com";
$emaildomains[] = "netx.waw.pl";
$emaildomains[] = "wiosenna.org";
$emaildomains[] = "polbox.com";
$emaildomains[] = "interia.pl";
$emaildomains[] = "o2.pl";
$emaildomains[] = "poczta.onet.pl";
$emaildomains[] = "kki.net.pl";
$emaildomains[] = "wp.pl";
$emaildomains[] = "rulez.pl";

$producer[] = "3Com";
$producer[] = "Planet";
$producer[] = "Cisco";
$producer[] = "Micronet";
$producer[] = "Surecom";
$producer[] = "D-Link";

function mkpw($nchars)
{
	$allowed="0123456789ABCDEF";
	mt_srand ((double) microtime() * 100000000);
	while (strlen($return)<$nchars) $return .= $allowed[mt_rand(0,strlen($allowed))];
	return $return;
}
				
function makemac()
{
	for($i = 0; $i < 6; $i ++)
		$mac[] = mkpw(2);
	return join(':',$mac);
}

$SMARTY->display('header.html');
echo '<H1>Generowanie danych losowych</H1>';
	
if(sprintf('%d',$_GET['l']) > 0 && sprintf('%d',$_GET['l']) <= 250)
{
	echo '<B>Czyszcz baz danych...</B><BR>';
	$DB->Execute('DELETE FROM nodes');
	$DB->Execute('DELETE FROM users');
	$DB->Execute('DELETE FROM cash');
	$DB->Execute('DELETE FROM assignments');
	$DB->Execute('DELETE FROM networks');
	$DB->Execute('DELETE FROM tariffs');
	$DB->Execute('DELETE FROM payments');	
	$DB->Execute('DELETE FROM netdevices');
	$DB->Execute('DELETE FROM netlinks');
	
	if($LMS->CONFIG['database']['type']=="postgres")
	{
		$DB->Execute("DROP SEQUENCE \"nodes_id_seq\"; CREATE SEQUENCE \"nodes_id_seq\"");
		$DB->Execute("DROP SEQUENCE \"users_id_seq\"; CREATE SEQUENCE \"users_id_seq\"");
		$DB->Execute("DROP SEQUENCE \"cash_id_seq\";  CREATE SEQUENCE \"cash_id_seq\"");
		$DB->Execute("DROP SEQUENCE \"assignments_id_seq\";CREATE SEQUENCE \"assignments_id_seq\"");
		$DB->Execute("DROP SEQUENCE \"networks_id_seq\";   CREATE SEQUENCE \"networks_id_seq\"");
		$DB->Execute("DROP SEQUENCE \"tariffs_id_seq\";    CREATE SEQUENCE \"tariffs_id_seq\"");
		$DB->Execute("DROP SEQUENCE \"netdevices_id_seq\"; CREATE SEQUENCE \"netdevices_id_seq\"");
		$DB->Execute("DROP SEQUENCE \"netlinks_id_seq\";   CREATE SEQUENCE \"netlinks_id_seq\"");
	}
	
	if($LMS->CONFIG['database']['type']=='mysql')
	{
		$DB->Execute('ALTER TABLE users auto_increment=0');
		$DB->Execute('ALTER TABLE nodes auto_increment=0');
		$DB->Execute('ALTER TABLE netdevices auto_increment=0');
		$DB->Execute('ALTER TABLE tariffs auto_increment=0');
	}

	echo '<B>Generuje taryfy...</B><BR>';
	$tariffdata = array( name => 'Lite', description => 'Taryfa Lite', value => '30', taxvalue => '7', pkwiu => '', uprate => '64', upceil=> '64', downrate => '128', downceil => '128', climit => '0', plimit => '0');
	$LMS->TariffAdd($tariffdata);
	$tariffdata = array( name => 'Standard', description => 'Taryfa Standard', value => '60', taxvalue => '7', pkwiu => '', uprate => '128', upceil => '128', downrate => '256', downceil => '256', climit => '0', plimit => '0');
	$LMS->TariffAdd($tariffdata);
	$tariffdata = array( name => 'Gold', description => 'Taryfa Gold', value => '120', taxvalue => '7', pkwiu => '', uprate => '256', upceil => '256', downrate => '512', downceil => '512', climit => '0', plimit => '0');
	$LMS->TariffAdd($tariffdata);

	echo '<B>Generuje opaty stae...</B><BR>';
	$paymentdata = array( name => 'DSL-512', description => 'Abonament za cze', value => '200', creditor => 'Internet Super Provider S.A.', period => '1', at => '10');
	$LMS->PaymentAdd($paymentdata);
	$paymentdata = array( name => 'Serwerownia', description => 'Wynajem lokalu', value => '300', creditor => 'Spdzielnia Mieszkaniowa "WIDOK"', period => '1', at => '20');
	$LMS->PaymentAdd($paymentdata);
	$paymentdata = array( name => 'Domena', description => 'Opata za domen "nasza.net"', value => '150', creditor => 'NASK', period => '3', at => '31');
	$LMS->PaymentAdd($paymentdata);
	
	echo '<B>Generuje sie...</B><BR>';
	$netdata = array( name => 'LAN1', address => '192.168.0.0', prefix => '22', gateway => '192.168.0.1', dns => '192.168.0.1', dns2 => '192.168.3.254', domain => 'ultralan.net.pl', wins => '192.168.0.2', dhcpstart => '192.168.3.230', dhcpend => '192.168.3.253');
	$LMS->NetworkAdd($netdata);

	echo '<B>Generuje uytkownikw...</B><BR>';	
	$startip = ip_long('192.168.0.0')+1;
	$cnt = 0;
	$lnsize = sizeof($lastnames);
	$nsize = sizeof($names);
	$ppsize = sizeof($phoneprefix);
	$ssize = sizeof($streets);
	$esize = sizeof($emaildomains);
	for($i = 0; $i < sprintf('%d',$_GET['l']); $i++)
	{
		$useradd['lastname'] = $lastnames[mt_rand(0,$lnsize-1)];
		$useradd['name'] = $names[mt_rand(0,$nsize-1)];
		$useradd['phone1'] = $phoneprefix[mt_rand(0,$ppsize-1)];
		for($j = 0; $j < 6; $j++)
			$useradd['phone1'] .= mt_rand(0,9);
		$street = mt_rand(0,$ssize-1);
		$useradd['address'] = $streets[$street].' '.mt_rand(1,50).' m '.mt_rand(1,300);
		$useradd['zip'] = '03-7'.sprintf('%02d',$street);
		$useradd['city'] = 'Warszawa';
		$useradd['email'] = strtolower($useradd['name']).'.'.strtolower($useradd['lastname']).'@'.$emaildomains[mt_rand(0,$esize-1)];
		$useradd['status'] = 3;
		$useradd['tariff'] = mt_rand(1,3);
		$useradd['payday'] = mt_rand(1,28);
		$useradd['gguin'] = 0;
		$useradd['phone2'] = '';
		$useradd['phone3'] = '';
		$useradd['nip'] = '';
		$useradd['pesel'] = '';
		$useradd['serviceaddr'] = '';
		$useradd['info'] = '';
		$useradd['message'] = '';
		$useradd['pin'] = rand(10000,99999);
		$id = $LMS->UserAdd($useradd);
		$LMS->AddAssignMent(array( 'tariffid' => $useradd['tariff'], 'userid' => $id, 'period' => 1, 'at' => $useradd['payday'], 'invoice' => 0, 'datefrom' => 0, 'dateto' => 0));
		$nodes = mt_rand(1,3);
		for($j = 0; $j < $nodes; $j++)
		{
			$nodedata['name'] = $nodenames[$cnt].$i;
			$cnt++;
			$startip++;
			$nodedata['ipaddr'] = long2ip($startip);
			$nodedata['mac'] = makemac();
			$nodedata['ownerid'] = $id;
			$nodedata['access'] = 1;
			$nodedata['warning'] = 0;
			if($nodeid = $LMS->NodeAdd($nodedata))
				$DB->Execute('UPDATE nodes SET lastonline=? WHERE id=? ', array(mt_rand(time()-2592000,time()+2592000),$nodeid));
		}
		$startip ++;
	}
	
	echo '<B>Generuje osprzt i poczenia sieciowe...</B><BR>';	
	$nodes = $DB->GetOne("SELECT count(id) FROM nodes");
	$sprod = sizeof($producer);
	$i = 0;
	while($nodes)
	{
		$i++;
		$prod = mt_rand(0,$sprod-1);
		$LMS->NetDevAdd(array(
			'name' => "SWITCH_".$i,
			'location' => $streets[mt_rand(0,$ssize-1)].' '.mt_rand(1,50),
			'description' => "",
			'producer' => $producer[$prod],
			'model' => "10/100 Mbps Switch",
			'serialnumber' => ($i*1000000+$i*200000)."-".($i*11111)."-".($i*33),
			'ports' => "16"));
		$ports = mt_rand(4,14);
		for($j = 0; $j < $ports; $j++)
		{
			if(!$nodes) break;
			$LMS->NetDevLinkNode($nodes,$i);
			$nodes--;
		}
		$ip['ownerid'] = 0;
		$ip['ipaddr'] = long2ip($startip); 
		$ip['mac'] = makemac();
		$ip['name'] = "SWITCH_".$i;
		$ip['access'] = 1;
		$ip['warning'] = 0;
		$LMS->NetDevLinkNode($LMS->NodeAdd($ip),$i);		
		$startip++;
		if($i>1)
			$LMS->NetDevLink($i,$i-1);
	}	
		
}else
	echo '<FORM METHOD="GET" ACTION="?"><INPUT TYPE="HIDDEN" VALUE="genfake" NAME="m">Ile rekordw wygenerowa? (max: 250, <FONT COLOR="RED">UWAGA! TO USUNIE WSZYSTKIE DANE Z BAZY!!!</FONT>) <INPUT TYPE="TEXT" NAME="l" SIZE="30"></FORM>';
	
$SMARTY->display('footer.html');

?>
